import 'package:equatable/equatable.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class Product extends Equatable {
  const Product({
    required this.uuid,
    required this.name,
    required this.productType,
  });

  final String uuid;
  final String name;
  final String productType;

  String get icon => _mapIconToProduct(productType);

  factory Product.fromJson(Map<String, dynamic> json) {
    return Product(
      uuid: json['uuid'] as String? ?? '',
      name: json['name'] as String? ?? '',
      productType: json['prodType'] as String? ?? '',
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'uuid': uuid,
      'name': name,
      'productType': productType,
    };
  }

  static String _mapIconToProduct(String prodType) {
    const iconMapping = {
      '1G': Assets.Gang1SwitchIcon,
      '1GT': Assets.oneTouchSwitch,
      '2G': Assets.Gang2SwitchIcon,
      '2GT': Assets.twoTouchSwitch,
      '3G': Assets.Gang3SwitchIcon,
      '3GT': Assets.threeTouchSwitch,
      'CUR': Assets.curtain,
      'CUR_2': Assets.curtain,
      'GD': Assets.garageDoor,
      'GW': Assets.SmartGatewayIcon,
      'DL': Assets.DoorLockIcon,
      'WL': Assets.waterLeakSensor,
      'WH': Assets.waterHeater,
      'WM': Assets.waterLeakSensor,
      'SOS': Assets.sos,
      'AC': Assets.ac,
      'CPS': Assets.presenceSensor,
      'PC': Assets.powerClamp,
      'WPS': Assets.presenceSensor,
      'DS': Assets.doorSensor
    };

    return iconMapping[prodType] ?? Assets.presenceSensor;
  }

  @override
  List<Object?> get props => [uuid, name, productType];
}
