import 'package:dio/dio.dart';
import 'package:syncrow_web/pages/common/bloc/project_manager.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/params/load_space_details_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/services/space_details_service.dart';
import 'package:syncrow_web/services/api/api_exception.dart';
import 'package:syncrow_web/services/api/http_service.dart';

class RemoteSpaceDetailsService implements SpaceDetailsService {
  final HTTPService _httpService;

  RemoteSpaceDetailsService({
    required HTTPService httpService,
  }) : _httpService = httpService;

  static const _defaultErrorMessage = 'Failed to load space details';

  @override
  Future<SpaceDetailsModel> getSpaceDetails(LoadSpaceDetailsParam param) async {
    try {
      final response = await _httpService.get(
        path: await _makeEndpoint(param),
        expectedResponseModel: (data) {
          final response = data as Map<String, dynamic>;
          return SpaceDetailsModel.fromJson(
            response['data'] as Map<String, dynamic>,
          );
        },
      );
      return response;
    } on DioException catch (e) {
      final message = e.response?.data as Map<String, dynamic>?;
      final error = message?['error'] as Map<String, dynamic>?;
      final errorMessage = error?['error'] as String? ?? '';
      final formattedErrorMessage = [_defaultErrorMessage, errorMessage].join(
        ': ',
      );
      throw APIException(formattedErrorMessage);
    } catch (e) {
      final formattedErrorMessage = [_defaultErrorMessage, '$e'].join(': ');
      throw APIException(formattedErrorMessage);
    }
  }

  Future<String> _makeEndpoint(LoadSpaceDetailsParam param) async {
    final projectUuid = await ProjectManager.getProjectUUID();
    if (projectUuid == null || projectUuid.isEmpty) {
      throw APIException('Project UUID is not set');
    }

    return '/projects/$projectUuid/communities/${param.communityUuid}/spaces/${param.spaceUuid}';
  }
}
