import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/params/load_space_details_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/services/space_details_service.dart';

class UniqueSubspacesDecorator implements SpaceDetailsService {
  final SpaceDetailsService _decoratee;

  const UniqueSubspacesDecorator(this._decoratee);

  @override
  Future<SpaceDetailsModel> getSpaceDetails(LoadSpaceDetailsParam param) async {
    final response = await _decoratee.getSpaceDetails(param);

    final uniqueSubspaces = <String, Subspace>{};

    for (final subspace in response.subspaces) {
      final normalizedName = subspace.name.trim().toLowerCase();
      if (!uniqueSubspaces.containsKey(normalizedName)) {
        uniqueSubspaces[normalizedName] = subspace;
      }
    }

    return response.copyWith(
      subspaces: uniqueSubspaces.values.toList(),
    );
  }
}
