import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/common/buttons/cancel_button.dart';
import 'package:syncrow_web/pages/common/buttons/default_button.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class SpaceDetailsActionButtons extends StatelessWidget {
  const SpaceDetailsActionButtons({
    super.key,
    required this.onSave,
    required this.onCancel,
    this.saveButtonLabel = 'OK',
    this.cancelButtonLabel = 'Cancel',
  });

  final VoidCallback onCancel;
  final VoidCallback? onSave;
  final String saveButtonLabel;
  final String cancelButtonLabel;

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      spacing: 10,
      children: [
        Expanded(child: _buildCancelButton(context)),
        Expanded(child: _buildSaveButton()),
      ],
    );
  }

  Widget _buildCancelButton(BuildContext context) {
    return CancelButton(onPressed: onCancel, label: cancelButtonLabel);
  }

  Widget _buildSaveButton() {
    return DefaultButton(
      onPressed: onSave,
      borderRadius: 10,
      backgroundColor: ColorsManager.secondaryColor,
      foregroundColor: ColorsManager.whiteColors,
      child: Text(saveButtonLabel),
    );
  }
}
