import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/space_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/communities_tree_selection_bloc/communities_tree_selection_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/params/load_space_details_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/bloc/space_details_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_details_form.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SpaceDetailsDialog extends StatefulWidget {
  const SpaceDetailsDialog({
    required this.title,
    required this.spaceModel,
    required this.onSave,
    required this.context,
    super.key,
  });

  final Widget title;
  final SpaceModel spaceModel;
  final void Function(SpaceDetailsModel space) onSave;
  final BuildContext context;

  @override
  State<SpaceDetailsDialog> createState() => _SpaceDetailsDialogState();
}

class _SpaceDetailsDialogState extends State<SpaceDetailsDialog> {
  @override
  void initState() {
    final isCreateMode = widget.spaceModel.uuid.isEmpty;

    if (!isCreateMode) {
      final param = LoadSpaceDetailsParam(
        spaceUuid: widget.spaceModel.uuid,
        communityUuid: widget.context
            .read<CommunitiesTreeSelectionBloc>()
            .state
            .selectedCommunity!
            .uuid,
      );
      widget.context.read<SpaceDetailsBloc>().add(LoadSpaceDetails(param));
    }
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final isCreateMode = widget.spaceModel.uuid.isEmpty;
    if (isCreateMode) {
      return SpaceDetailsForm(
        title: widget.title,
        space: SpaceDetailsModel.empty(),
        onSave: widget.onSave,
      );
    }

    return BlocBuilder<SpaceDetailsBloc, SpaceDetailsState>(
      bloc: widget.context.read<SpaceDetailsBloc>(),
      builder: (context, state) => switch (state) {
        SpaceDetailsInitial() => _buildLoadingDialog(),
        SpaceDetailsLoading() => _buildLoadingDialog(),
        SpaceDetailsLoaded(:final spaceDetails) => SpaceDetailsForm(
            title: widget.title,
            space: spaceDetails,
            onSave: widget.onSave,
          ),
        SpaceDetailsFailure(:final errorMessage) => _buildErrorDialog(
            errorMessage,
          ),
      },
    );
  }

  Widget _buildLoadingDialog() {
    return AlertDialog(
      title: widget.title,
      backgroundColor: ColorsManager.whiteColors,
      content: SizedBox(
        height: context.screenHeight * 0.3,
        width: context.screenWidth * 0.5,
        child: const Center(child: CircularProgressIndicator()),
      ),
    );
  }

  Widget _buildErrorDialog(String errorMessage) {
    return AlertDialog(
      title: widget.title,
      backgroundColor: ColorsManager.whiteColors,
      content: Center(
        child: SelectableText(
          errorMessage,
          style: context.textTheme.bodyLarge?.copyWith(
            color: ColorsManager.red,
            fontWeight: FontWeight.w500,
            fontSize: 18,
          ),
        ),
      ),
    );
  }
}
