import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_details_action_buttons.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_details_devices_box.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_icon_picker.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_name_text_field.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_sub_spaces_box.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_space/presentation/bloc/space_details_model_bloc/space_details_model_bloc.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SpaceDetailsForm extends StatelessWidget {
  const SpaceDetailsForm({
    required this.title,
    required this.space,
    required this.onSave,
    super.key,
  });

  final Widget title;
  final SpaceDetailsModel space;
  final void Function(SpaceDetailsModel space) onSave;

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (context) => SpaceDetailsModelBloc(initialState: space),
      child: BlocBuilder<SpaceDetailsModelBloc, SpaceDetailsModel>(
          buildWhen: (previous, current) => previous != current,
          builder: (context, space) {
            return AlertDialog(
              title: title,
              backgroundColor: ColorsManager.whiteColors,
              content: SizedBox(
                height: context.screenHeight * 0.3,
                width: context.screenWidth * 0.5,
                child: Row(
                  spacing: 20,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Expanded(child: SpaceIconPicker(iconPath: space.icon)),
                    Expanded(
                      flex: 2,
                      child: Column(
                        mainAxisSize: MainAxisSize.min,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          SpaceNameTextField(
                            initialValue: space.spaceName,
                            isNameFieldExist: (value) => space.subspaces.any(
                              (subspace) => subspace.name == value,
                            ),
                          ),
                          const Spacer(),
                          SpaceSubSpacesBox(
                            subspaces: space.subspaces,
                          ),
                          const SizedBox(height: 16),
                          SpaceDetailsDevicesBox(space: space),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
              actions: [
                SpaceDetailsActionButtons(
                  onSave: () => onSave(space),
                  onCancel: Navigator.of(context).pop,
                ),
              ],
            );
          }),
    );
  }
}
