import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_icon_selection_dialog.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_space/presentation/bloc/space_details_model_bloc/space_details_model_bloc.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SpaceIconPicker extends StatelessWidget {
  const SpaceIconPicker({
    required this.iconPath,
    super.key,
  });

  final String iconPath;

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Stack(
        
        alignment: Alignment.center,
        children: [
          Container(
            width: context.screenWidth * 0.175,
            height: context.screenHeight * 0.175,
            decoration: const BoxDecoration(
              color: ColorsManager.boxColor,
              shape: BoxShape.circle,
            ),
            padding: const EdgeInsets.all(24),
            child: SvgPicture.asset(
              iconPath,
              width: context.screenWidth * 0.08,
              height: context.screenHeight * 0.08,
            ),
          ),
          Positioned.directional(
            top: 12,
            start: context.screenHeight * 0.06,
            textDirection: Directionality.of(context),
            child: InkWell(
              onTap: () {
                showDialog<String?>(
                  context: context,
                  builder: (context) => SpaceIconSelectionDialog(
                    selectedIcon: iconPath,
                  ),
                ).then((value) {
                  if (value != null) {
                    if (context.mounted) {
                      context.read<SpaceDetailsModelBloc>().add(
                            UpdateSpaceDetailsIcon(value),
                          );
                    }
                  }
                });
              },
              child: Container(
                decoration: const BoxDecoration(
                  shape: BoxShape.circle,
                ),
                child: SvgPicture.asset(
                  Assets.iconEdit,
                  width: 16,
                  height: 16,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
