import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SpaceIconSelectionDialog extends StatelessWidget {
  const SpaceIconSelectionDialog({super.key, required this.selectedIcon});
  final String selectedIcon;

  static const List<String> _icons = [
    Assets.location,
    Assets.villa,
    Assets.gym,
    Assets.sauna,
    Assets.bbq,
    Assets.building,
    Assets.desk,
    Assets.door,
    Assets.parking,
    Assets.pool,
    Assets.stair,
    Assets.steamRoom,
    Assets.street,
    Assets.unit,
  ];

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: SelectableText(
        'Space Icon',
        style: context.textTheme.headlineMedium,
      ),
      backgroundColor: ColorsManager.whiteColors,
      content: Container(
        width: context.screenWidth * 0.45,
        height: context.screenHeight * 0.275,
        padding: const EdgeInsets.all(12),
        decoration: BoxDecoration(
          color: ColorsManager.boxColor,
          borderRadius: BorderRadius.circular(12),
        ),
        child: GridView.builder(
          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 7,
            crossAxisSpacing: 8,
            mainAxisSpacing: 16,
          ),
          itemCount: _icons.length,
          itemBuilder: (context, index) {
            final isSelected = selectedIcon == _icons[index];
            return Container(
              padding: const EdgeInsetsDirectional.all(2),
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                border: isSelected
                    ? Border.all(color: ColorsManager.vividBlue, width: 2)
                    : null,
              ),
              child: IconButton(
                onPressed: () => Navigator.of(context).pop(_icons[index]),
                icon: SvgPicture.asset(
                  _icons[index],
                  width: context.screenWidth * 0.03,
                  height: context.screenHeight * 0.08,
                ),
              ),
            );
          },
        ),
      ),
    );
  }
}
