import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/common/edit_chip.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/button_content_widget.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_sub_spaces_dialog.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/subspace_name_display_widget.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_space/presentation/bloc/space_details_model_bloc/space_details_model_bloc.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class SpaceSubSpacesBox extends StatelessWidget {
  const SpaceSubSpacesBox({super.key, required this.subspaces});

  final List<Subspace> subspaces;

  @override
  Widget build(BuildContext context) {
    if (subspaces.isEmpty) {
      return TextButton(
        style: TextButton.styleFrom(
          padding: EdgeInsets.zero,
          overlayColor: ColorsManager.transparentColor,
        ),
        onPressed: () => _showSubSpacesDialog(context),
        child: const SizedBox(
          width: double.infinity,
          child: ButtonContentWidget(
            svgAssets: Assets.addIcon,
            label: 'Create Sub Spaces',
          ),
        ),
      );
    } else {
      return Container(
        padding: const EdgeInsets.all(8.0),
        width: double.infinity,
        decoration: BoxDecoration(
          color: ColorsManager.textFieldGreyColor,
          borderRadius: BorderRadius.circular(15),
          border: Border.all(
            color: ColorsManager.textFieldGreyColor,
            width: 3.0,
          ),
        ),
        child: Wrap(
          spacing: 8.0,
          runSpacing: 8.0,
          children: [
            ...subspaces.map((e) => SubspaceNameDisplayWidget(subSpace: e)),
            EditChip(
              onTap: () => _showSubSpacesDialog(context),
            ),
          ],
        ),
      );
    }
  }

  void _showSubSpacesDialog(BuildContext context) {
    showDialog<void>(
      context: context,
      barrierDismissible: false,
      builder: (_) => SpaceSubSpacesDialog(
        subspaces: subspaces,
        onSave: (subspaces) {
          context.read<SpaceDetailsModelBloc>().add(
                UpdateSpaceDetailsSubspaces(subspaces),
              );
        },
      ),
    );
  }
}
