import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/subspace_chip.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SubSpacesInput extends StatefulWidget {
  const SubSpacesInput({
    super.key,
    required this.subSpaces,
    required this.onSubspaceAdded,
    required this.onSubspaceDeleted,
  });

  final List<Subspace> subSpaces;
  final void Function(String name) onSubspaceAdded;
  final void Function(String uuid) onSubspaceDeleted;

  @override
  State<SubSpacesInput> createState() => _SubSpacesInputState();
}

class _SubSpacesInputState extends State<SubSpacesInput> {
  late final TextEditingController _subspaceNameController;
  late final FocusNode _focusNode;
  @override
  void initState() {
    super.initState();
    _subspaceNameController = TextEditingController();
    _focusNode = FocusNode();
  }

  @override
  void dispose() {
    _subspaceNameController.dispose();
    _focusNode.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: context.screenWidth * 0.35,
      padding: const EdgeInsets.symmetric(
        vertical: 10,
        horizontal: 16,
      ),
      decoration: BoxDecoration(
        color: ColorsManager.boxColor,
        borderRadius: BorderRadius.circular(10),
      ),
      child: Wrap(
        spacing: 8,
        runSpacing: 8,
        alignment: WrapAlignment.start,
        crossAxisAlignment: WrapCrossAlignment.center,
        children: [
          ...widget.subSpaces.asMap().entries.map(
            (entry) {
              final index = entry.key;
              final subSpace = entry.value;

              final lowerName = subSpace.name.toLowerCase();

              final duplicateIndices = widget.subSpaces
                  .asMap()
                  .entries
                  .where((e) => e.value.name.toLowerCase() == lowerName)
                  .map((e) => e.key)
                  .toList();
              final isDuplicate = duplicateIndices.length > 1 &&
                  duplicateIndices.indexOf(index) != 0;
              return SubspaceChip(
                subSpace: subSpace,
                isDuplicate: isDuplicate,
                onDeleted: () => widget.onSubspaceDeleted(subSpace.uuid),
              );
            },
          ),
          SizedBox(
            width: 200,
            child: TextField(
              focusNode: _focusNode,
              controller: _subspaceNameController,
              decoration: InputDecoration(
                border: InputBorder.none,
                hintText: widget.subSpaces.isEmpty ? 'Please enter the name' : null,
                hintStyle: context.textTheme.bodySmall?.copyWith(
                  color: ColorsManager.lightGrayColor,
                ),
              ),
              onSubmitted: (value) {
                final trimmedValue = value.trim();
                if (trimmedValue.isNotEmpty) {
                  widget.onSubspaceAdded(trimmedValue);
                  _subspaceNameController.clear();
                  _focusNode.requestFocus();
                }
              },
              style: context.textTheme.bodyMedium,
            ),
          ),
        ],
      ),
    );
  }
}
