import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/products/data/services/remote_products_service.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/products/presentation/bloc/products_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/tags/presentation/widgets/products_grid.dart';
import 'package:syncrow_web/services/api/http_service.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class AddDeviceTypeWidget extends StatelessWidget {
  const AddDeviceTypeWidget({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (_) => ProductsBloc(RemoteProductsService(HTTPService()))
        ..add(const LoadProducts()),
      child: Builder(
        builder: (context) => AlertDialog(
          title: const Text('Add Devices'),
          backgroundColor: ColorsManager.whiteColors,
          content: BlocBuilder<ProductsBloc, ProductsState>(
            builder: (context, state) => switch (state) {
              ProductsInitial() => _buildLoading(context),
              ProductsLoading() => _buildLoading(context),
              ProductsLoaded(:final products) => ProductsGrid(
                  products: products,
                ),
              ProductsFailure(:final errorMessage) => _buildFailure(
                  context,
                  errorMessage,
                ),
            },
          ),
        ),
      ),
    );
  }

  Widget _buildLoading(BuildContext context) => SizedBox(
        width: context.screenWidth * 0.9,
        height: context.screenHeight * 0.65,
        child: const Center(child: CircularProgressIndicator()),
      );

  Widget _buildFailure(BuildContext context, String errorMessage) {
    return SizedBox(
      width: context.screenWidth * 0.9,
      height: context.screenHeight * 0.65,
      child: Center(
        child: SelectableText(
          errorMessage,
          style: context.textTheme.bodyMedium?.copyWith(
            color: context.theme.colorScheme.error,
          ),
        ),
      ),
    );
  }
}
