import 'package:flutter/material.dart';
import 'package:syncrow_web/common/dialog_dropdown.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/tags/domain/models/tag.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/tags/presentation/widgets/product_tag_field.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';
import 'package:uuid/uuid.dart';

class AssignTagsTable extends StatefulWidget {
  const AssignTagsTable({
    required this.productAllocations,
    super.key,
  });

  final List<ProductAllocation> productAllocations;

  @override
  State<AssignTagsTable> createState() => _AssignTagsTableState();
}

class _AssignTagsTableState extends State<AssignTagsTable> {
  List<TextEditingController> _controllers = [];

  @override
  void initState() {
    super.initState();
    _controllers = List.generate(
      widget.productAllocations.length,
      (index) => TextEditingController(
        text: widget.productAllocations[index].product.name,
      ),
    );
  }

  @override
  void dispose() {
    for (final controller in _controllers) {
      controller.dispose();
    }
    super.dispose();
  }

  DataColumn _buildDataColumn(String label) {
    return DataColumn(label: Text(label, style: context.textTheme.bodyMedium));
  }

  @override
  Widget build(BuildContext context) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(20),
      child: DataTable(
        headingRowColor: WidgetStateProperty.all(ColorsManager.dataHeaderGrey),
        key: ValueKey(widget.productAllocations.length),
        border: TableBorder.all(
          color: ColorsManager.dataHeaderGrey,
          width: 1,
          borderRadius: BorderRadius.circular(20),
        ),
        columns: [
          _buildDataColumn('#'),
          _buildDataColumn('Device'),
          _buildDataColumn('Tag'),
          _buildDataColumn('Location'),
        ],
        rows: widget.productAllocations.isEmpty
            ? [
                DataRow(
                  cells: [
                    DataCell(
                      Center(
                        child: Text(
                          'No Devices Available',
                          style: context.textTheme.bodyMedium?.copyWith(
                            color: ColorsManager.lightGrayColor,
                          ),
                        ),
                      ),
                    ),
                    DataCell.empty,
                    DataCell.empty,
                    DataCell.empty,
                  ],
                ),
              ]
            : List.generate(widget.productAllocations.length, (index) {
                final productAllocation = widget.productAllocations[index];
                final controller = _controllers[index];

                return DataRow(
                  cells: [
                    DataCell(Text((index + 1).toString())),
                    DataCell(
                      Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Expanded(
                              child: Text(
                            productAllocation.product.name,
                            overflow: TextOverflow.ellipsis,
                          )),
                          const SizedBox(width: 10),
                          Container(
                            width: 20,
                            height: 20,
                            decoration: BoxDecoration(
                              shape: BoxShape.circle,
                              border: Border.all(
                                color: ColorsManager.lightGrayColor,
                                width: 1,
                              ),
                            ),
                            child: IconButton(
                              icon: const Icon(
                                Icons.close,
                                color: ColorsManager.lightGreyColor,
                                size: 16,
                              ),
                              onPressed: () {
                                // TODO: Delete the product allocation
                              },
                              tooltip: 'Delete Tag',
                              padding: EdgeInsets.zero,
                              constraints: const BoxConstraints(),
                            ),
                          ),
                        ],
                      ),
                    ),
                    DataCell(
                      Container(
                        alignment: Alignment.centerLeft,
                        width: double.infinity,
                        child: ProductTagField(
                          key: ValueKey('dropdown_${const Uuid().v4()}_$index'),
                          productName: productAllocation.product.uuid,
                          initialValue: null,
                          onSelected: (value) {
                            controller.text = value.name;
                          },
                          items: const [
                            Tag(
                              uuid: '',
                              name: 'Tag',
                              createdAt: '',
                              updatedAt: '',
                            ),
                          ],
                        ),
                      ),
                    ),
                    DataCell(
                      SizedBox(
                          width: double.infinity,
                          child: DialogDropdown(
                            items: const [],
                            // items: widget.locations,
                            selectedValue: productAllocation.tag.name.isEmpty
                                ? 'Main Space'
                                : productAllocation.tag.name,
                            onSelected: (value) {},
                          )),
                    ),
                  ],
                );
              }),
      ),
    );
  }
}
