import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/products/domain/models/product.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/tags/presentation/widgets/product_type_card_counter.dart';
import 'package:syncrow_web/pages/spaces_management/tag_model/widgets/device_icon_widget.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class ProductTypeCard extends StatelessWidget {
  const ProductTypeCard({
    required this.product,
    required this.count,
    required this.onIncrement,
    required this.onDecrement,
    super.key,
  });

  final Product product;
  final int count;
  final void Function() onIncrement;
  final void Function() onDecrement;

  @override
  Widget build(BuildContext context) {
    return Card(
      elevation: 2,
      color: ColorsManager.whiteColors,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
      child: Padding(
        padding: const EdgeInsets.all(4),
        child: Column(
          spacing: 8,
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Expanded(child: DeviceIconWidget(icon: product.icon)),
            _buildName(context, product.name),
            ProductTypeCardCounter(
              onIncrement: onIncrement,
              onDecrement: onDecrement,
              count: count,
            ),
            const SizedBox(height: 4),
          ],
        ),
      ),
    );
  }

  Widget _buildName(BuildContext context, String name) {
    return Expanded(
      child: SizedBox(
        height: 35,
        child: Text(
          name,
          style: context.textTheme.bodySmall?.copyWith(
            color: ColorsManager.blackColor,
          ),
          textAlign: TextAlign.center,
          maxLines: 2,
          overflow: TextOverflow.ellipsis,
        ),
      ),
    );
  }
}
