import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class ProductTypeCardCounter extends StatelessWidget {
  const ProductTypeCardCounter({
    super.key,
    required this.onIncrement,
    required this.onDecrement,
    required this.count,
  });

  final int count;
  final void Function() onIncrement;
  final void Function() onDecrement;

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.symmetric(horizontal: 10, vertical: 5),
      decoration: BoxDecoration(
        color: ColorsManager.counterBackgroundColor,
        borderRadius: BorderRadius.circular(20),
      ),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        spacing: 8,
        children: [
          _buildCounterButton(
            Icons.remove,
            onDecrement,
          ),
          Text(
            count.toString(),
            style: context.textTheme.bodyLarge?.copyWith(
              color: ColorsManager.spaceColor,
            ),
          ),
          _buildCounterButton(Icons.add, onIncrement),
        ],
      ),
    );
  }

  Widget _buildCounterButton(
    IconData icon,
    VoidCallback onPressed,
  ) {
    return GestureDetector(
      onTap: onPressed,
      child: Icon(
        icon,
        color: ColorsManager.spaceColor.withValues(alpha: 0.3),
        size: 18,
      ),
    );
  }
}
