import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/products/domain/models/product.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/tags/presentation/widgets/product_type_card.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class ProductsGrid extends StatelessWidget {
  const ProductsGrid({required this.products, super.key});

  final List<Product> products;

  @override
  Widget build(BuildContext context) {
    final size = MediaQuery.of(context).size;
    final crossAxisCount = switch (context.screenWidth) {
      > 1200 => 8,
      > 800 => 5,
      _ => 3,
    };
    return SingleChildScrollView(
      child: Container(
        width: size.width * 0.9,
        height: size.height * 0.65,
        decoration: BoxDecoration(
          color: ColorsManager.textFieldGreyColor,
          borderRadius: BorderRadius.circular(8),
        ),
        child: Column(
          children: [
            const SizedBox(height: 16),
            Expanded(
              child: GridView.builder(
                padding: const EdgeInsets.symmetric(
                  horizontal: 20,
                ),
                shrinkWrap: true,
                gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                  crossAxisCount: crossAxisCount,
                  mainAxisSpacing: 6,
                  crossAxisSpacing: 4,
                  childAspectRatio: 0.8,
                ),
                itemCount: products.length,
                itemBuilder: (context, index) => ProductTypeCard(
                  product: products[index],
                  count: 0,
                  onIncrement: () {},
                  onDecrement: () {},
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
