import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/main_module/shared/helpers/space_management_community_dialog_helper.dart';
import 'package:syncrow_web/pages/space_management_v2/main_module/shared/widgets/community_dialog.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/community_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/bloc/communities_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/communities_tree_selection_bloc/communities_tree_selection_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_community/data/services/remote_update_community_service.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_community/presentation/bloc/update_community_bloc.dart';
import 'package:syncrow_web/services/api/http_service.dart';

class EditCommunityDialog extends StatelessWidget {
  const EditCommunityDialog({
    required this.community,
    required this.parentContext,
    super.key,
  });

  final CommunityModel community;
  final BuildContext parentContext;

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (_) => UpdateCommunityBloc(
        RemoteUpdateCommunityService(HTTPService()),
      ),
      child: BlocConsumer<UpdateCommunityBloc, UpdateCommunityState>(
        listener: (context, state) {
          switch (state) {
            case UpdateCommunityInitial() || UpdateCommunityLoading():
              SpaceManagementCommunityDialogHelper.showLoadingDialog(context);
              break;
            case UpdateCommunitySuccess(:final community):
              _onUpdateCommunitySuccess(context, community);
              break;
            case UpdateCommunityFailure():
              Navigator.of(context).pop();
              break;
          }
        },
        builder: (context, state) => CommunityDialog(
          title: const Text('Edit Community'),
          initialName: community.name,
          errorMessage: state is UpdateCommunityFailure ? state.errorMessage : null,
          onSubmit: (name) => context.read<UpdateCommunityBloc>().add(
                UpdateCommunity(community.copyWith(name: name)),
              ),
        ),
      ),
    );
  }

  void _onUpdateCommunitySuccess(
    BuildContext context,
    CommunityModel community,
  ) {
    Navigator.of(context).pop();
    Navigator.of(context).pop();
    SpaceManagementCommunityDialogHelper.showSuccessSnackBar(
      context,
      '${community.name} community updated successfully',
    );
    parentContext.read<CommunitiesBloc>().add(
          CommunitiesUpdateCommunity(community),
        );
    parentContext.read<CommunitiesTreeSelectionBloc>().add(
          SelectCommunityEvent(community: community),
        );
  }
}
